@@ -248,11 +248,11 @@ Row<eT>::operator=(const std::vector<eT>& x)
   const Row<eT>&
   Row<eT>::operator=(Row<eT>&& X)
     {
-    arma_extra_debug_sigprint();
+    arma_extra_debug_sigprint(arma_boost::format("this = %x   X = %x") % this % &X);
     
     (*this).steal_mem(X);
     
-    if( (X.mem_state == 0) && (X.n_elem <= arma_config::mat_prealloc) )
+    if( (X.mem_state == 0) && (X.n_elem <= arma_config::mat_prealloc) && (this != &X) )
       {
       access::rw(X.n_rows) = 1;
       access::rw(X.n_cols) = 0;
@@ -664,6 +664,66 @@ Row<eT>::operator()(const span& col_span) const
 
 
 
+template<typename eT>
+arma_inline
+subview_row<eT>
+Row<eT>::head(const uword N)
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_check( (N > Mat<eT>::n_cols), "Row::head(): size out of bounds");
+  
+  return subview_row<eT>(*this, 0, 0, N);
+  }
+
+
+
+template<typename eT>
+arma_inline
+const subview_row<eT>
+Row<eT>::head(const uword N) const
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_check( (N > Mat<eT>::n_cols), "Row::head(): size out of bounds");
+  
+  return subview_row<eT>(*this, 0, 0, N);
+  }
+
+
+
+template<typename eT>
+arma_inline
+subview_row<eT>
+Row<eT>::tail(const uword N)
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_check( (N > Mat<eT>::n_cols), "Row::tail(): size out of bounds");
+  
+  const uword start_col = Mat<eT>::n_cols - N;
+  
+  return subview_row<eT>(*this, 0, start_col, N);
+  }
+
+
+
+template<typename eT>
+arma_inline
+const subview_row<eT>
+Row<eT>::tail(const uword N) const
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_check( (N > Mat<eT>::n_cols), "Row::tail(): size out of bounds");
+  
+  const uword start_col = Mat<eT>::n_cols - N;
+  
+  return subview_row<eT>(*this, 0, start_col, N);
+  }
+
+
+
 //! remove specified columns
 template<typename eT>
 inline
