@@ -47,7 +47,20 @@ arma_inline
 int
 arma_rng_cxx98::randi_val()
   {
-  return std::rand();
+  #if (RAND_MAX == 32767)
+    {
+    u32 val1 = u32(std::rand());
+    u32 val2 = u32(std::rand());
+    
+    val1 <<= 15;
+    
+    return (val1 | val2);
+    }
+  #else
+    {
+    return std::rand();
+    }
+  #endif
   }
 
 
@@ -56,7 +69,7 @@ arma_inline
 double
 arma_rng_cxx98::randu_val()
   {
-  return double( double(std::rand()) * ( double(1) / double(RAND_MAX) ) );
+  return double( double(randi_val()) * ( double(1) / double(randi_max_val()) ) );
   }
 
 
@@ -75,8 +88,8 @@ arma_rng_cxx98::randn_val()
   
   do
     {
-    tmp1 = double(2) * double(std::rand()) * (double(1) / double(RAND_MAX)) - double(1);
-    tmp2 = double(2) * double(std::rand()) * (double(1) / double(RAND_MAX)) - double(1);
+    tmp1 = double(2) * double(randi_val()) * (double(1) / double(randi_max_val())) - double(1);
+    tmp2 = double(2) * double(randi_val()) * (double(1) / double(randi_max_val())) - double(1);
     
     w = tmp1*tmp1 + tmp2*tmp2;
     }
@@ -101,8 +114,8 @@ arma_rng_cxx98::randn_dual_val(eT& out1, eT& out2)
   
   do
     {
-    tmp1 = eTp(2) * eTp(std::rand()) * (eTp(1) / eTp(RAND_MAX)) - eTp(1);
-    tmp2 = eTp(2) * eTp(std::rand()) * (eTp(1) / eTp(RAND_MAX)) - eTp(1);
+    tmp1 = eTp(2) * eTp(randi_val()) * (eTp(1) / eTp(randi_max_val())) - eTp(1);
+    tmp2 = eTp(2) * eTp(randi_val()) * (eTp(1) / eTp(randi_max_val())) - eTp(1);
     
     w = tmp1*tmp1 + tmp2*tmp2;
     }
@@ -132,11 +145,11 @@ arma_rng_cxx98::randi_fill(eT* mem, const uword N, const int a, const int b)
     {
     const uword length = b - a + 1;
     
-    const double scale = double(length) / double(RAND_MAX);
+    const double scale = double(length) / double(randi_max_val());
     
     for(uword i=0; i<N; ++i)
       {
-      mem[i] = (std::min)( b, (int( double(std::rand()) * scale ) + a) );
+      mem[i] = (std::min)( b, (int( double(randi_val()) * scale ) + a) );
       }
     }
   }
@@ -147,7 +160,11 @@ inline
 int
 arma_rng_cxx98::randi_max_val()
   {
-  return RAND_MAX;
+  #if (RAND_MAX == 32767)
+    return ( (32767 << 15) + 32767);
+  #else
+    return RAND_MAX;
+  #endif
   }
 
 
