@@ -2940,6 +2940,66 @@ subview_col<eT>::subvec(const uword in_row1, const uword in_row2) const
 
 
 
+template<typename eT>
+inline
+subview_col<eT>
+subview_col<eT>::head(const uword N)
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_check( (N > subview<eT>::n_rows), "subview_col::head(): size out of bounds");
+  
+  return subview_col<eT>(this->m, this->aux_col1, this->aux_row1, N);
+  }
+
+
+
+template<typename eT>
+inline
+const subview_col<eT>
+subview_col<eT>::head(const uword N) const
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_check( (N > subview<eT>::n_rows), "subview_col::head(): size out of bounds");
+  
+  return subview_col<eT>(this->m, this->aux_col1, this->aux_row1, N);
+  }
+
+
+
+template<typename eT>
+inline
+subview_col<eT>
+subview_col<eT>::tail(const uword N)
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_check( (N > subview<eT>::n_rows), "subview_col::tail(): size out of bounds");
+  
+  const uword start_row = subview<eT>::n_rows - N;
+  
+  return subview_col<eT>(this->m, this->aux_col1, start_row, N);
+  }
+
+
+
+template<typename eT>
+inline
+const subview_col<eT>
+subview_col<eT>::tail(const uword N) const
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_check( (N > subview<eT>::n_rows), "subview_col::tail(): size out of bounds");
+  
+  const uword start_row = subview<eT>::n_rows - N;
+  
+  return subview_col<eT>(this->m, this->aux_col1, start_row, N);
+  }
+
+
+
 //
 //
 //
@@ -3248,6 +3308,66 @@ subview_row<eT>::subvec(const uword in_col1, const uword in_col2) const
 
 
 
+template<typename eT>
+inline
+subview_row<eT>
+subview_row<eT>::head(const uword N)
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_check( (N > subview<eT>::n_cols), "subview_row::head(): size out of bounds");
+  
+  return subview_row<eT>(this->m, this->aux_row1, this->aux_col1, N);
+  }
+
+
+
+template<typename eT>
+inline
+const subview_row<eT>
+subview_row<eT>::head(const uword N) const
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_check( (N > subview<eT>::n_cols), "subview_row::head(): size out of bounds");
+  
+  return subview_row<eT>(this->m, this->aux_row1, this->aux_col1, N);
+  }
+
+
+
+template<typename eT>
+inline
+subview_row<eT>
+subview_row<eT>::tail(const uword N)
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_check( (N > subview<eT>::n_cols), "subview_row::tail(): size out of bounds");
+  
+  const uword start_col = subview<eT>::n_cols - N;
+  
+  return subview_row<eT>(this->m, this->aux_row1, start_col, N);
+  }
+
+
+
+template<typename eT>
+inline
+const subview_row<eT>
+subview_row<eT>::tail(const uword N) const
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_check( (N > subview<eT>::n_cols), "subview_row::tail(): size out of bounds");
+  
+  const uword start_col = subview<eT>::n_cols - N;
+  
+  return subview_row<eT>(this->m, this->aux_row1, start_col, N);
+  }
+
+
+
 //
 //
 //
