@@ -724,9 +724,9 @@ struct partial_unwrap_default
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>&) const { return false; }
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -748,9 +748,9 @@ struct partial_unwrap_fixed
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -793,9 +793,9 @@ struct partial_unwrap< Mat<eT> >
     arma_extra_debug_sigprint();
     }
   
-  inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return ((&X) == (&M)); }
+  arma_inline bool is_alias(const Mat<eT>& X) const { return ((&X) == (&M)); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -817,9 +817,9 @@ struct partial_unwrap< Row<eT> >
     arma_extra_debug_sigprint();
     }
   
-  inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -841,9 +841,9 @@ struct partial_unwrap< Col<eT> >
     arma_extra_debug_sigprint();
     }
   
-  inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -866,9 +866,9 @@ struct partial_unwrap< subview_col<eT> >
     arma_extra_debug_sigprint();
     }
   
-  inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&orig)); }
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&orig)); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -891,9 +891,9 @@ struct partial_unwrap< subview_row<eT> >
     arma_extra_debug_sigprint();
     }
   
-  inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>&) const { return false; }
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -916,9 +916,9 @@ struct partial_unwrap_htrans_default
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>&) const { return false; }
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -940,9 +940,9 @@ struct partial_unwrap_htrans_fixed
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -986,7 +986,7 @@ struct partial_unwrap< Op< Mat<eT>, op_htrans> >
   
   arma_inline eT get_val() const { return eT(1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -1010,7 +1010,7 @@ struct partial_unwrap< Op< Row<eT>, op_htrans> >
   
   arma_inline eT get_val() const { return eT(1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -1034,7 +1034,7 @@ struct partial_unwrap< Op< Col<eT>, op_htrans> >
   
   arma_inline eT get_val() const { return eT(1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -1059,7 +1059,7 @@ struct partial_unwrap< Op< subview_col<eT>, op_htrans> >
   
   arma_inline eT get_val() const { return eT(1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&orig)); }
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&orig)); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -1084,7 +1084,7 @@ struct partial_unwrap< Op< subview_row<eT>, op_htrans> >
   
   arma_inline eT get_val() const { return eT(1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>&) const { return false; }
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -1110,7 +1110,7 @@ struct partial_unwrap_htrans2_default
   
   arma_inline eT get_val() const { return val; }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>&) const { return false; }
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
   
   static const bool do_trans = true;
   static const bool do_times = true;
@@ -1287,9 +1287,9 @@ struct partial_unwrap< Op< subview_row<eT>, op_htrans2> >
     arma_extra_debug_sigprint();
     }
   
-  inline eT get_val() const { return val; }
+  arma_inline eT get_val() const { return val; }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>&) const { return false; }
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
   
   static const bool do_trans = true;
   static const bool do_times = true;
@@ -1314,9 +1314,9 @@ struct partial_unwrap_scalar_times_default
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return val; }
+  arma_inline eT get_val() const { return val; }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>&) const { return false; }
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -1498,9 +1498,9 @@ struct partial_unwrap< eOp<subview_row<eT>, eop_scalar_times> >
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return val; }
+  arma_inline eT get_val() const { return val; }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>&) const { return false; }
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -1524,9 +1524,9 @@ struct partial_unwrap_neg_default
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>&) const { return false; }
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -1549,9 +1549,9 @@ struct partial_unwrap_neg_fixed
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -1597,9 +1597,9 @@ struct partial_unwrap< eOp<Mat<eT>, eop_neg> >
     arma_extra_debug_sigprint();
     }
   
-  inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -1621,9 +1621,9 @@ struct partial_unwrap< eOp<Row<eT>, eop_neg> >
     arma_extra_debug_sigprint();
     }
   
-  inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -1645,9 +1645,9 @@ struct partial_unwrap< eOp<Col<eT>, eop_neg> >
     arma_extra_debug_sigprint();
     }
   
-  inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&M)); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -1670,9 +1670,9 @@ struct partial_unwrap< eOp<subview_col<eT>, eop_neg> >
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&orig)); }
+  arma_inline bool is_alias(const Mat<eT>& X) const { return (void_ptr(&X) == void_ptr(&orig)); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -1695,9 +1695,9 @@ struct partial_unwrap< eOp<subview_row<eT>, eop_neg> >
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
-  arma_hot arma_inline bool is_alias(const Mat<eT>&) const { return false; }
+  arma_inline bool is_alias(const Mat<eT>&) const { return false; }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -1724,7 +1724,7 @@ struct partial_unwrap_check_default
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -1755,7 +1755,7 @@ struct partial_unwrap_check_fixed
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -1810,7 +1810,7 @@ struct partial_unwrap_check< Mat<eT> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -1844,7 +1844,7 @@ struct partial_unwrap_check< Row<eT> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -1878,7 +1878,7 @@ struct partial_unwrap_check< Col<eT> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -1904,7 +1904,7 @@ struct partial_unwrap_check< subview_col<eT> >
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = false;
   static const bool do_times = false;
@@ -1927,7 +1927,7 @@ struct partial_unwrap_check_htrans_default
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -1958,7 +1958,7 @@ struct partial_unwrap_check_htrans_fixed
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -2013,7 +2013,7 @@ struct partial_unwrap_check< Op< Mat<eT>, op_htrans> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -2046,7 +2046,7 @@ struct partial_unwrap_check< Op< Row<eT>, op_htrans> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -2079,7 +2079,7 @@ struct partial_unwrap_check< Op< Col<eT>, op_htrans> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -2105,7 +2105,7 @@ struct partial_unwrap_check< Op< subview_col<eT>, op_htrans> >
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(1); }
+  arma_inline eT get_val() const { return eT(1); }
   
   static const bool do_trans = true;
   static const bool do_times = false;
@@ -2553,7 +2553,7 @@ struct partial_unwrap_check_neg_default
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -2585,7 +2585,7 @@ struct partial_unwrap_check_neg_fixed
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -2640,7 +2640,7 @@ struct partial_unwrap_check< eOp<Mat<eT>, eop_neg> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -2672,7 +2672,7 @@ struct partial_unwrap_check< eOp<Row<eT>, eop_neg> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -2704,7 +2704,7 @@ struct partial_unwrap_check< eOp<Col<eT>, eop_neg> >
     if(M_local) { delete M_local; }
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
@@ -2729,7 +2729,7 @@ struct partial_unwrap_check< eOp<subview_col<eT>, eop_neg> >
     arma_extra_debug_sigprint();
     }
   
-  arma_hot arma_inline eT get_val() const { return eT(-1); }
+  arma_inline eT get_val() const { return eT(-1); }
   
   static const bool do_trans = false;
   static const bool do_times = true;
